## Overview
This crate provides a self-contained Rust library for converting [Vega-Lite](https://vega.github.io/vega-lite/) visualization specifications into various formats.  The conversions are performed using the Vega-Lite and Vega JavaScript libraries running in a v8 JavaScript runtime provided by the [`deno_runtime`](https://crates.io/crates/deno_runtime) crate.

This crate is a dependency of the [`vl-convert`](https://crates.io/crates/vl-convert) CLI application crate and the [`vl-convert-python`](https://pypi.org/project/vl-convert-python/) Python library.

## Example
The [`VlConverter`] struct may be used to perform various Vega-Lite conversions. See the documentation of [`VlConverter`] for example usage.

## JavaScript Vendoring and Code Generation
Note: The `vl-convert-rs/vendor` directory and `vl-convert-rs/src/module_loader/import_map.rs` file in this crate are generated by the internal [`vl-convert-vendor`](https://github.com/jonmmease/vl-convert/tree/main/vl-convert-vendor) crate.
